// Copyright 2024 Patial Tech (Ankit Patial).
//
// This file is part of code.patial.tech/go/appcore, which is MIT licensed.
// See http://opensource.org/licenses/MIT

package jwt

import (
	"fmt"
	"testing"
	"time"

	"code.patial.tech/go/appcore/crypto"
)

/*
-----BEGIN PUBLIC KEY-----
MCowBQYDK2VwAyEA9JTCYl3OQwuVTSf0PsBkmgJSt7e5Tbk3jKnB90vDqXA=
-----END PUBLIC KEY-----

-----BEGIN PRIVATE KEY-----
MC4CAQAwBQYDK2VwBCIEIMMkYUKJ9P0gp+Rm9mR4i0KUBT9nFUzxzxjH7sC0xq/F
-----END PRIVATE KEY-----
*/

func TestSign2(t *testing.T) {
	key, err := crypto.ParseEdPrivateKey([]byte(`-----BEGIN PRIVATE KEY-----
MC4CAQAwBQYDK2VwBCIEIMMkYUKJ9P0gp+Rm9mR4i0KUBT9nFUzxzxjH7sC0xq/F
-----END PRIVATE KEY-----`))
	if err != nil {
		t.Fatal(err)
	}

	s, err := Sign(key, map[string]any{"name": "ankit", "age": 25}, "blackdu", time.Second)
	if err != nil {
		t.Fatal(err)
	}

	println(s)
}

func TestExprired(t *testing.T) {
	privKey, err := crypto.ParseEdPrivateKey([]byte(`-----BEGIN PRIVATE KEY-----
MC4CAQAwBQYDK2VwBCIEIMMkYUKJ9P0gp+Rm9mR4i0KUBT9nFUzxzxjH7sC0xq/F
-----END PRIVATE KEY-----`))
	if err != nil {
		t.Error(err)
	}

	// payload := "eyJhbGciOiJFZERTQSIsInR5cCI6IkpXVCJ9.eyJhZ2UiOjI1LCJleHAiOjE3NDQxMjAxNzUsImlhdCI6MTc0NDEyMDE3NCwiaXNzIjoiYmxhY2tkdSIsIm5hbWUiOiJhbmtpdCJ9.W6OQHMRdcRiPS398p8u0vLjpq34oxYPDengillXSFEDXJVXOkzl0ncCpju0yuMOhrQLRRG0EJLKfoFcAxsbpDA"
	payload, err := Sign(privKey, map[string]any{"name": "ankit", "age": 25}, "blackdu", time.Second)
	if err != nil {
		t.Fatal(err)
	}

	claims, err := Parse(privKey, payload, "blackdu")
	if err != nil {
		t.Fatal(err)
	}

	fmt.Printf("%v", claims)
}
